@@ -6,8 +6,7 @@ test -z "$srcdir" && srcdir=.
 
 PKG_NAME="webapps"
 
-(test -f $srcdir/configure.ac \
-  && test -d $srcdir/src) || {
+test -f $srcdir/configure.ac || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
     echo " top-level webapps directory"
     exit 1
@@ -18,4 +17,4 @@ which gnome-autogen.sh || {
     echo "your OS vendor's package manager)."
     exit 1
 }
-USE_GNOME2_MACROS=1 USE_COMMON_DOC_BUILD=yes . gnome-autogen.sh
\ No newline at end of file
+USE_GNOME2_MACROS=1 USE_COMMON_DOC_BUILD=yes . gnome-autogen.sh
